#
# compose.py - A python class to represent a compose, and read/write a datafile
# for it.
#
# Will Woods <wwoods@redhat.com>
#
# Copyright 2006, 2007 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc. 
#

from snake.tree import Debug, Source, Tree, IsoSet
import os.path

class Compose(object):
    def __init__(self, **kwargs):
        self.name="" # human readable string
        self.time=0.0
        # these should be lists of the corresponding objects
        self.trees=[]
        self.isos=[]
        self.debug=[]
        self.source=[]
        if 'dir' in kwargs:
            self.loaddir(kwargs['dir'])

    def loaddir(self,dir):
        composeinfofile=os.path.join(dir,'.composeinfo')
        if os.path.exists(composeinfofile):
            return self.parsecomposeinfo(composeinfofile)

    def parsecomposeinfo(self,composeinfo):
        f=open(composeinfo)
        self.name=os.path.basename(os.path.dirname(composeinfo))
        for line in f.readlines():
            (type,info) = line.split(":")
            if type == 'tree':
                dir = os.path.join(os.path.dirname(composeinfo),info.strip())
                t=Tree()
                t.reldir = info.strip()
                t.compose=self.name
                t.loaddir(dir)
                self.trees.append(t)
            # FIXME: add other types

    def __repr__(self):
        return "Compose(%s)" % self.name

    def __str__(self):
        return "%s%s" % (self.name, str(self.trees))
