#
# defaults.py - a sample default python kickstart template
#
# Copyright 2006, 2007 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc.
#

from snake.kickstart import SnakeHandler
from pykickstart.constants import *
from pykickstart.version import FC3,FC4,F11

class Defaults(SnakeHandler):
    '''Basic default kickstart object'''
    def __init__(self):
        SnakeHandler.__init__(self)
        self.rootpw(isCrypted=False, password="snake")
        self.firewall(enabled=False)
        self.autopart(autopart=True)
        self.bootloader(location="mbr")
        self.clearpart(initAll=True,type=CLEARPART_TYPE_ALL,drives=[])
        # default timezone/keyboard - you can override this at your site
        self.timezone(timezone='America/New_York', isUtc=True)
        self.keyboard(keyboard='us')
        self.lang(lang='en_US')
        # normally we want to reboot into the new system when we're finished
        self.reboot(action=KS_REBOOT, eject=False)

        if self.version <= FC4:
            self.langsupport(deflang='en_US.UTF-8', supported=["en_US.UTF-8"])

        if self.version < FC3:
            self.mouse(mouse="none")
            self.skipx(skipx=True)

    def __str__(self):

        # For F11 and newer, a display mode is required in kickstart to
        # guaruntee a fully automated install.  If displayMode or VNC hasn't
        # been provided by the kickstart template, do so now.
        if self.version >= F11 \
            and self.displaymode.displayMode == None \
            and not self.vnc.enabled:
            self.vnc(enabled=True)

        return SnakeHandler.__str__(self)

# no ks() function - this isn't a usable template

